@@ -27,22 +27,26 @@ class AppMenu:
         
     def about_clicked(self,widget):
         QtGui.QMessageBox.about(self.menu, "About BuildNotify",
-        "<b>BuildNotify</b> v 0.1 has been developed using PyQt4 and serves as a build notification tool for cruise control. In case of any suggestions/bugs," +
+        "<b>BuildNotify</b> has been developed using PyQt4 and serves as a build notification tool for cruise control. In case of any suggestions/bugs," +
         "please visit <a href=\"http://bitbucket.org/Anay/buildnotify\">http://bitbucket.org/Anay/buildnotify</a> and provide your feedback.")
 
     def preferences_clicked(self, widget):
-        self.preferences_dialog = PreferencesDialog(self.conf.get_urls())
+        self.preferences_dialog = PreferencesDialog(self.conf)
         self.preferences_dialog.show()
         if self.preferences_dialog.exec_() == QtGui.QDialog.Accepted:
-            self.conf.update_urls(self.preferences_dialog.get_urls())
-            
+            self.preferences_dialog.save()
+                
     def exit(self,widget):
         sys.exit()
 
     def create_menu_item(self, label, icon, url, lastBuildTime):
-        action = self.menu.addAction(icon, label + ", " + DistanceOfTime(lastBuildTime).age() + " ago")
+        menu_item_label = label
+        if self.conf.get_value("lastBuildTimeForProject") == True:
+            menu_item_label = label + ", " + DistanceOfTime(lastBuildTime, self.conf.get_timezone()).age() + " ago"
+            
+        action = self.menu.addAction(icon, menu_item_label)
         receiver = lambda url=url: self.open_url(self, url)
         QtCore.QObject.connect(action, QtCore.SIGNAL('triggered()'), receiver)
 
     def open_url(self, something, url) :
-        os.system(str(self.conf.browser.toString()) + " " + url + " &")
+        os.system(self.conf.get_browser() + " " + url + " &")
