@@ -3,11 +3,12 @@ from datetime import datetime
 import pytz
 
 class DistanceOfTime:
-    def __init__(self, from_date):
+    def __init__(self, from_date, timezone):
         self.from_date = from_date
+        self.timezone = timezone
         
     def age(self):
-        since_date = datetime.now(tz=pytz.timezone('US/Central')).replace(tzinfo=None)
+        since_date = datetime.now(tz=pytz.timezone(self.timezone)).replace(tzinfo=None)
 
         distance_in_time = since_date - self.from_date
         distance_in_seconds = int(round(abs(distance_in_time.days * 86400 + distance_in_time.seconds)))
